summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirsaver.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
commite8d62395de6c1b3844294c5b6c09428c315ac42a (patch)
treef94a43e157b5b4607f3a8d5b9b7be873d458fafa /kdirstat/kdirsaver.cpp
parent1ed26cd2c4d896ae560dc7dddb570fe14ef573f3 (diff)
downloadkdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.tar.gz
kdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.zip
TQt4 port kdirstat
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1239296 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirsaver.cpp')
-rw-r--r--kdirstat/kdirsaver.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdirstat/kdirsaver.cpp b/kdirstat/kdirsaver.cpp
index 2be9074..2f1b79d 100644
--- a/kdirstat/kdirsaver.cpp
+++ b/kdirstat/kdirsaver.cpp
@@ -13,11 +13,11 @@
#include "kdirsaver.h"
-KDirSaver::KDirSaver( const QString & newPath )
+KDirSaver::KDirSaver( const TQString & newPath )
{
/*
* No need to actually save the current working directory: This object
* includes a QDir whose default constructor constructs a directory object
* that contains the current working directory. Just what is needed here.
*/
@@ -45,7 +45,7 @@ KDirSaver::~KDirSaver()
void
-KDirSaver::cd( const QString & newPath )
+KDirSaver::cd( const TQString & newPath )
{
if ( ! newPath.isEmpty() )
{
@@ -54,10 +54,10 @@ KDirSaver::cd( const QString & newPath )
}
-QString
+TQString
KDirSaver::currentDirPath() const
{
- return QDir::currentDirPath();
+ return TQDir::currentDirPath();
}
@@ -13,11 +13,11 @@
/*
* No need to actually save the current working directory: This object
- * includes a QDir whose default constructor constructs a directory object
+ * includes a TQDir whose default constructor constructs a directory object
* that contains the current working directory. Just what is needed here.
*/